"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_service_1 = require("../services/config.service");
const cli_utils_1 = require("../utils/cli.utils");
const errors_utils_1 = require("../utils/errors.utils");
const drive_database_manager_service_1 = require("../services/database/drive-database-manager.service");
class Logout extends core_1.Command {
    static args = {};
    static description = 'Logs out the current internxt user that is logged into the Internxt CLI.';
    static aliases = [];
    static examples = ['<%= config.bin %> <%= command.id %>'];
    static flags = {};
    static enableJsonFlag = true;
    run = async () => {
        const user = await config_service_1.ConfigService.instance.readUser();
        if (user) {
            await config_service_1.ConfigService.instance.clearUser();
            await drive_database_manager_service_1.DriveDatabaseManager.clean();
            const message = 'User logged out successfully.';
            cli_utils_1.CLIUtils.success(this.log.bind(this), message);
            return { success: true, message };
        }
        else {
            const message = 'No user is currently logged in.';
            cli_utils_1.CLIUtils.error(this.log.bind(this), message);
            return { success: false, message };
        }
    };
    catch = async (error) => {
        errors_utils_1.ErrorUtils.report(this.error.bind(this), error, { command: this.id });
        cli_utils_1.CLIUtils.error(this.log.bind(this), error.message);
        this.exit(1);
    };
}
exports.default = Logout;
