"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_service_1 = require("../services/config.service");
const cli_utils_1 = require("../utils/cli.utils");
const command_types_1 = require("../types/command.types");
const validation_service_1 = require("../services/validation.service");
const errors_utils_1 = require("../utils/errors.utils");
const trash_service_1 = require("../services/drive/trash.service");
class TrashFolder extends core_1.Command {
    static args = {};
    static description = 'Moves a given folder to the trash.';
    static aliases = ['trash:folder'];
    static examples = ['<%= config.bin %> <%= command.id %>'];
    static flags = {
        ...cli_utils_1.CLIUtils.CommonFlags,
        id: core_1.Flags.string({
            char: 'i',
            description: 'The folder id to be trashed.',
            required: false,
        }),
    };
    static enableJsonFlag = true;
    run = async () => {
        const { flags } = await this.parse(TrashFolder);
        const nonInteractive = flags['non-interactive'];
        const userCredentials = await config_service_1.ConfigService.instance.readUser();
        if (!userCredentials)
            throw new command_types_1.MissingCredentialsError();
        const uuid = await this.getFolderUuid(flags['id'], nonInteractive);
        await trash_service_1.TrashService.instance.trashItems({ items: [{ uuid, type: 'folder' }] });
        const message = 'Folder trashed successfully.';
        cli_utils_1.CLIUtils.success(this.log.bind(this), message);
        return { success: true, message, folder: { uuid } };
    };
    catch = async (error) => {
        errors_utils_1.ErrorUtils.report(this.error.bind(this), error, { command: this.id });
        cli_utils_1.CLIUtils.error(this.log.bind(this), error.message);
        this.exit(1);
    };
    getFolderUuid = async (folderUuidFlag, nonInteractive) => {
        const folderUuid = await cli_utils_1.CLIUtils.getValueFromFlag({
            value: folderUuidFlag,
            name: TrashFolder.flags['id'].name,
        }, {
            nonInteractive,
            prompt: {
                message: 'What is the folder id you want to trash?',
                options: { type: 'input' },
            },
        }, {
            validate: validation_service_1.ValidationService.instance.validateUUIDv4,
            error: new command_types_1.NotValidFolderUuidError(),
        }, this.log.bind(this));
        return folderUuid;
    };
}
exports.default = TrashFolder;
