"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const config_service_1 = require("../services/config.service");
const cli_utils_1 = require("../utils/cli.utils");
const errors_utils_1 = require("../utils/errors.utils");
const command_types_1 = require("../types/command.types");
const validation_service_1 = require("../services/validation.service");
class WebDAVConfig extends core_1.Command {
    static args = {};
    static description = 'Edit the configuration of the Internxt CLI WebDav server as the port or the protocol.';
    static aliases = [];
    static examples = ['<%= config.bin %> <%= command.id %>'];
    static flags = {
        port: core_1.Flags.string({
            char: 'p',
            description: 'The new port for the WebDAV server.',
            required: false,
        }),
        https: core_1.Flags.boolean({
            char: 's',
            description: 'Configures the WebDAV server to use HTTPS with self-signed certificates.',
            required: false,
            exclusive: ['http'],
        }),
        http: core_1.Flags.boolean({
            char: 'h',
            description: 'Configures the WebDAV server to use insecure plain HTTP.',
            required: false,
            exclusive: ['https'],
        }),
    };
    static enableJsonFlag = true;
    run = async () => {
        const { flags } = await this.parse(WebDAVConfig);
        const webdavConfig = await config_service_1.ConfigService.instance.readWebdavConfig();
        const port = flags['port'];
        if (port) {
            if (validation_service_1.ValidationService.instance.validateTCPIntegerPort(port)) {
                webdavConfig['port'] = port;
            }
            else {
                throw new command_types_1.NotValidPortError();
            }
        }
        const http = flags['http'];
        if (http) {
            webdavConfig['protocol'] = 'http';
        }
        const https = flags['https'];
        if (https) {
            webdavConfig['protocol'] = 'https';
        }
        await config_service_1.ConfigService.instance.saveWebdavConfig(webdavConfig);
        const message = `On the next start, the WebDAV server will use the next config: ${JSON.stringify(webdavConfig)}`;
        cli_utils_1.CLIUtils.success(this.log.bind(this), message);
        return { success: true, message, config: webdavConfig };
    };
    catch = async (error) => {
        errors_utils_1.ErrorUtils.report(this.error.bind(this), error, { command: this.id });
        cli_utils_1.CLIUtils.error(this.log.bind(this), error.message);
        this.exit(1);
    };
}
exports.default = WebDAVConfig;
