"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const cli_utils_1 = require("../utils/cli.utils");
const errors_utils_1 = require("../utils/errors.utils");
const config_service_1 = require("../services/config.service");
const validation_service_1 = require("../services/validation.service");
const drive_database_manager_service_1 = require("../services/database/drive-database-manager.service");
class Whoami extends core_1.Command {
    static args = {};
    static description = 'Display the current user logged into the Internxt CLI.';
    static aliases = [];
    static examples = ['<%= config.bin %> <%= command.id %>'];
    static flags = {};
    static enableJsonFlag = true;
    run = async () => {
        const userCredentials = await config_service_1.ConfigService.instance.readUser();
        if (!userCredentials) {
            const message = 'You are not logged in.';
            cli_utils_1.CLIUtils.error(this.log.bind(this), message);
            return { success: false, message };
        }
        else {
            const validCreds = this.checkUserAndTokens(userCredentials);
            if (!validCreds) {
                const message = 'Your session has expired. You have been logged out. Please log in again.';
                await config_service_1.ConfigService.instance.clearUser();
                await drive_database_manager_service_1.DriveDatabaseManager.clean();
                cli_utils_1.CLIUtils.error(this.log.bind(this), message);
                return { success: false, message };
            }
            else {
                const message = `You are logged in as: ${userCredentials.user.email}.`;
                cli_utils_1.CLIUtils.success(this.log.bind(this), message);
                return { success: true, message, login: userCredentials };
            }
        }
    };
    catch = async (error) => {
        errors_utils_1.ErrorUtils.report(this.error.bind(this), error, { command: this.id });
        cli_utils_1.CLIUtils.error(this.log.bind(this), error.message);
        this.exit(1);
    };
    checkUserAndTokens = (loginCreds) => {
        if (!(loginCreds?.newToken && loginCreds?.token && loginCreds?.user?.mnemonic)) {
            return false;
        }
        const oldTokenDetails = validation_service_1.ValidationService.instance.validateTokenAndCheckExpiration(loginCreds.token);
        const newTokenDetails = validation_service_1.ValidationService.instance.validateTokenAndCheckExpiration(loginCreds.newToken);
        const goodMnemonic = validation_service_1.ValidationService.instance.validateMnemonic(loginCreds.user.mnemonic);
        const goodToken = oldTokenDetails.isValid && !oldTokenDetails.expiration.expired;
        const goodNewToken = newTokenDetails.isValid && !newTokenDetails.expiration.expired;
        return goodToken && goodNewToken && goodMnemonic;
    };
}
exports.default = Whoami;
