"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriveFileRepository = void 0;
const drive_file_model_1 = require("./drive-file.model");
const drive_file_domain_1 = require("./drive-file.domain");
class DriveFileRepository {
    findByRelativePath = async (relativePath) => {
        const file = await drive_file_model_1.DriveFileModel.findOne({
            where: {
                relativePath,
            },
        });
        return file ? this.toDomain(file) : null;
    };
    findById = async (id) => {
        const file = await drive_file_model_1.DriveFileModel.findByPk(id);
        return file ? this.toDomain(file) : null;
    };
    deleteById = async (id) => {
        await drive_file_model_1.DriveFileModel.destroy({ where: { id } });
    };
    createFile = async (driveFileItem, relativePath) => {
        const driveFile = drive_file_domain_1.DriveFile.build({
            ...driveFileItem,
            relativePath,
        });
        const newFile = await drive_file_model_1.DriveFileModel.create({ ...driveFile.toJSON() });
        return this.toDomain(newFile);
    };
    toDomain = (model) => {
        const driveFile = drive_file_domain_1.DriveFile.build({
            ...model.toJSON(),
        });
        return driveFile;
    };
    static clean = () => {
        return drive_file_model_1.DriveFileModel.drop();
    };
}
exports.DriveFileRepository = DriveFileRepository;
