"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriveFolderRepository = void 0;
const drive_folder_domain_1 = require("./drive-folder.domain");
const drive_folder_model_1 = require("./drive-folder.model");
class DriveFolderRepository {
    findByRelativePath = async (relativePath) => {
        const folder = await drive_folder_model_1.DriveFolderModel.findOne({
            where: {
                relativePath,
            },
        });
        return folder ? this.toDomain(folder) : null;
    };
    findById = async (id) => {
        const folder = await drive_folder_model_1.DriveFolderModel.findByPk(id);
        return folder ? this.toDomain(folder) : null;
    };
    deleteById = async (id) => {
        await drive_folder_model_1.DriveFolderModel.destroy({ where: { id } });
    };
    createFolder = async (driveFolderItem, relativePath) => {
        const driveFolder = drive_folder_domain_1.DriveFolder.build({
            ...driveFolderItem,
            relativePath,
        });
        const newFolder = await drive_folder_model_1.DriveFolderModel.create({ ...driveFolder.toJSON() });
        return this.toDomain(newFolder);
    };
    toDomain = (model) => {
        const driveFolder = drive_folder_domain_1.DriveFolder.build({
            ...model.toJSON(),
        });
        return driveFolder;
    };
    static clean = () => {
        return drive_folder_model_1.DriveFolderModel.drop();
    };
}
exports.DriveFolderRepository = DriveFolderRepository;
