"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriveFileService = void 0;
const sdk_manager_service_1 = require("../sdk-manager.service");
const drive_utils_1 = require("../../utils/drive.utils");
class DriveFileService {
    static instance = new DriveFileService();
    createFile = async (payload) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(true);
        const driveFile = await storageClient.createFileEntryByUuid(payload);
        return {
            name: payload.plain_name,
            encryptedName: driveFile.name,
            id: driveFile.id,
            uuid: driveFile.uuid,
            size: driveFile.size,
            bucket: driveFile.bucket,
            createdAt: new Date(driveFile.createdAt),
            updatedAt: new Date(driveFile.updatedAt),
            fileId: driveFile.fileId,
            type: driveFile.type,
            status: driveFile.status,
            folderId: driveFile.folderId,
            folderUuid: driveFile.folderUuid,
        };
    };
    getFileMetadata = async (uuid) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(true);
        const [getFileMetadata] = storageClient.getFile(uuid);
        const fileMetadata = await getFileMetadata;
        return drive_utils_1.DriveUtils.driveFileMetaToItem(fileMetadata);
    };
    moveFile = (payload) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(true);
        return storageClient.moveFileByUuid(payload);
    };
    renameFile = (fileUuid, payload) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(true);
        return storageClient.updateFileMetaByUUID(fileUuid, payload);
    };
    getFileMetadataByPath = async (path) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(true);
        const fileMetadata = await storageClient.getFileByPath(encodeURIComponent(path));
        return drive_utils_1.DriveUtils.driveFileMetaToItem(fileMetadata);
    };
    createThumbnail = (payload) => {
        const storageClient = sdk_manager_service_1.SdkManager.instance.getStorage(false);
        return storageClient.createThumbnailEntry(payload);
    };
}
exports.DriveFileService = DriveFileService;
