"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThumbnailService = void 0;
const node_stream_1 = require("node:stream");
const drive_file_service_1 = require("./drive/drive-file.service");
const drive_1 = require("@internxt/sdk/dist/drive");
const thumbnail_utils_1 = require("../utils/thumbnail.utils");
const sharp_1 = __importDefault(require("sharp"));
class ThumbnailService {
    static instance = new ThumbnailService();
    uploadThumbnail = async (fileContent, fileType, userBucket, file_id, networkFacade) => {
        let thumbnailBuffer;
        if ((0, thumbnail_utils_1.isImageThumbnailable)(fileType)) {
            thumbnailBuffer = await this.getThumbnailFromImageBuffer(fileContent);
        }
        if (thumbnailBuffer) {
            const size = thumbnailBuffer.length;
            const fileId = await new Promise((resolve, reject) => {
                networkFacade.uploadFile(node_stream_1.Readable.from(thumbnailBuffer), size, userBucket, (err, res) => {
                    if (err) {
                        return reject(err);
                    }
                    resolve(res);
                }, () => { });
            });
            const createdThumbnailFile = await drive_file_service_1.DriveFileService.instance.createThumbnail({
                file_id: file_id,
                max_width: thumbnail_utils_1.ThumbnailConfig.MaxWidth,
                max_height: thumbnail_utils_1.ThumbnailConfig.MaxHeight,
                type: thumbnail_utils_1.ThumbnailConfig.Type,
                size: size,
                bucket_id: userBucket,
                bucket_file: fileId,
                encrypt_version: drive_1.StorageTypes.EncryptionVersion.Aes03,
            });
            return createdThumbnailFile;
        }
    };
    getThumbnailFromImageBuffer = (buffer) => {
        return (0, sharp_1.default)(buffer)
            .resize({
            height: thumbnail_utils_1.ThumbnailConfig.MaxHeight,
            width: thumbnail_utils_1.ThumbnailConfig.MaxWidth,
            fit: 'inside',
        })
            .png({
            quality: thumbnail_utils_1.ThumbnailConfig.Quality,
        })
            .toBuffer();
    };
}
exports.ThumbnailService = ThumbnailService;
