"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DELETERequestHandler = void 0;
const webdav_utils_1 = require("../../utils/webdav.utils");
const logger_utils_1 = require("../../utils/logger.utils");
class DELETERequestHandler {
    dependencies;
    constructor(dependencies) {
        this.dependencies = dependencies;
    }
    handle = async (req, res) => {
        const { driveDatabaseManager, driveFileService, driveFolderService, trashService } = this.dependencies;
        const resource = await webdav_utils_1.WebDavUtils.getRequestedResource(req);
        logger_utils_1.webdavLogger.info(`[DELETE] Request received for ${resource.type} at ${resource.url}`);
        const driveItem = await webdav_utils_1.WebDavUtils.getAndSearchItemFromResource({
            resource,
            driveDatabaseManager,
            driveFolderService,
            driveFileService: driveFileService,
        });
        logger_utils_1.webdavLogger.info(`[DELETE] [${driveItem.uuid}] Trashing ${resource.type}`);
        await trashService.trashItems({
            items: [{ type: resource.type, uuid: driveItem.uuid }],
        });
        if (resource.type === 'folder') {
            await driveDatabaseManager.deleteFolderById(driveItem.id);
        }
        else if (resource.type === 'file') {
            await driveDatabaseManager.deleteFileById(driveItem.id);
        }
        res.status(204).send();
        const type = resource.type.charAt(0).toUpperCase() + resource.type.substring(1);
        logger_utils_1.webdavLogger.info(`[DELETE] [${driveItem.uuid}] ${type} trashed successfully`);
    };
}
exports.DELETERequestHandler = DELETERequestHandler;
