"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MKCOLRequestHandler = void 0;
const webdav_utils_1 = require("../../utils/webdav.utils");
const logger_utils_1 = require("../../utils/logger.utils");
const xml_utils_1 = require("../../utils/xml.utils");
const async_utils_1 = require("../../utils/async.utils");
class MKCOLRequestHandler {
    dependencies;
    constructor(dependencies) {
        this.dependencies = dependencies;
    }
    handle = async (req, res) => {
        const { driveDatabaseManager, driveFolderService } = this.dependencies;
        const resource = await webdav_utils_1.WebDavUtils.getRequestedResource(req);
        logger_utils_1.webdavLogger.info(`[MKCOL] Request received for ${resource.type} at ${resource.url}`);
        const parentResource = await webdav_utils_1.WebDavUtils.getRequestedResource(resource.parentPath);
        const parentFolderItem = (await webdav_utils_1.WebDavUtils.getAndSearchItemFromResource({
            resource: parentResource,
            driveDatabaseManager,
            driveFolderService,
        }));
        const [createFolder] = driveFolderService.createFolder({
            plainName: resource.path.base,
            parentFolderUuid: parentFolderItem.uuid,
        });
        const newFolder = await createFolder;
        logger_utils_1.webdavLogger.info(`[MKCOL] ✅ Folder created with UUID ${newFolder.uuid}`);
        await driveDatabaseManager.createFolder({
            name: newFolder.plainName,
            status: 'EXISTS',
            encryptedName: newFolder.name,
            bucket: newFolder.bucket,
            id: newFolder.id,
            parentId: newFolder.parentId,
            parentUuid: newFolder.parentUuid,
            uuid: newFolder.uuid,
            createdAt: new Date(newFolder.createdAt),
            updatedAt: new Date(newFolder.updatedAt),
        }, resource.url);
        await async_utils_1.AsyncUtils.sleep(500);
        res.status(201).send(xml_utils_1.XMLUtils.toWebDavXML({}, {}));
    };
}
exports.MKCOLRequestHandler = MKCOLRequestHandler;
