import { ApiSecurity, ApiUrl, AppDetails } from '../../shared';
import { CreateCheckoutSessionPayload, CreatedSubscriptionData, CreatePaymentSessionPayload, CustomerBillingInfo, DisplayPrice, FreeTrialAvailable, Invoice, InvoicePayload, PaymentMethod, ProductData, RedeemCodePayload, UpdateSubscriptionPaymentMethod, UserSubscription, UserType } from './types';
export declare class Payments {
    private readonly client;
    private readonly appDetails;
    private readonly apiSecurity;
    static client(apiUrl: ApiUrl, appDetails: AppDetails, apiSecurity: ApiSecurity): Payments;
    private constructor();
    createCustomer(name: string, email: string, country?: string, companyVatId?: string): Promise<{
        customerId: string;
        token: string;
    }>;
    createSubscription(customerId: string, priceId: string, token: string, quantity: number, currency?: string, promoCodeId?: string): Promise<CreatedSubscriptionData>;
    createPaymentIntent(customerId: string, amount: number, planId: string, token: string, currency?: string, promoCodeName?: string): Promise<{
        clientSecret: string;
        id: string;
        invoiceStatus?: string;
    }>;
    /**
     * Fetches the existing products and its details
     */
    getProducts(): Promise<ProductData[]>;
    /**
     * Creates and returns a new session identifier for the client to go to payment platform
     * @param payload
     */
    createSession(payload: CreatePaymentSessionPayload): Promise<{
        id: string;
    }>;
    getSetupIntent(userType?: UserType): Promise<{
        clientSecret: string;
    }>;
    getDefaultPaymentMethod(userType?: UserType): Promise<PaymentMethod>;
    getInvoices({ subscriptionId, startingAfter, limit }: InvoicePayload): Promise<Invoice[]>;
    isCouponUsedByUser({ couponCode }: {
        couponCode: string;
    }): Promise<{
        couponUsed: boolean;
    }>;
    getUserSubscription(userType?: UserType): Promise<UserSubscription>;
    getPrices(currency?: string, userType?: UserType): Promise<DisplayPrice[]>;
    requestPreventCancellation(): Promise<FreeTrialAvailable>;
    preventCancellation(): Promise<void>;
    applyRedeemCode(payload: RedeemCodePayload): Promise<void>;
    updateSubscriptionPaymentMethod(payload: UpdateSubscriptionPaymentMethod): Promise<void | Error>;
    updateSubscriptionPrice({ priceId, couponCode, userType, }: {
        priceId: string;
        couponCode?: string;
        userType: UserType;
    }): Promise<{
        userSubscription: UserSubscription;
        request3DSecure: boolean;
        clientSecret: string;
    }>;
    updateWorkspaceMembers(workspaceId: string, subscriptionId: string, updatedSeats: number): Promise<unknown>;
    cancelSubscription(userType?: UserType): Promise<void>;
    createCheckoutSession(payload: CreateCheckoutSessionPayload): Promise<{
        sessionId: string;
    }>;
    updateCustomerBillingInfo(payload: CustomerBillingInfo): Promise<void>;
    /**
     * Returns the needed headers for the module requests
     * @private
     */
    private headers;
}
