"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Users = exports.UserTypes = void 0;
var headers_1 = require("../../shared/headers");
var client_1 = require("../../shared/http/client");
exports.UserTypes = __importStar(require("./types"));
var Users = /** @class */ (function () {
    function Users(apiUrl, appDetails, apiSecurity) {
        this.client = client_1.HttpClient.create(apiUrl, apiSecurity.unauthorizedCallback);
        this.appDetails = appDetails;
        this.apiSecurity = apiSecurity;
    }
    Users.client = function (apiUrl, appDetails, apiSecurity) {
        return new Users(apiUrl, appDetails, apiSecurity);
    };
    /**
     * Sends an invitation to the specified email
     * @param email
     */
    Users.prototype.sendInvitation = function (email) {
        return this.client.post('/user/invite', {
            email: email,
        }, this.headers());
    };
    /**
     * Initialize basic state of user and returns data after registration process
     * @param email
     * @param mnemonic
     */
    Users.prototype.initialize = function (email, mnemonic) {
        return this.client
            .post('/initialize', {
            email: email,
            mnemonic: mnemonic,
        }, this.headers())
            .then(function (data) {
            return data.user;
        });
    };
    /**
     * Returns fresh data of the user
     */
    Users.prototype.refreshUser = function () {
        return this.client.get('/user/refresh', this.headers());
    };
    /**
     * Retrieves the user data for a specific user identified by the uuid.
     *
     * @param {string} params.userUuid - The UUID of the user.
     * @return {Promise<Object>} A promise that resolves to an object containing the user data.
     * The object has the following properties:
     * - `newToken` (string): The new token of the user.
     * - `oldToken` (string): The old drive token of the user.
     * - `user` (UserSettings): The user data.
     */
    Users.prototype.getUserData = function (_a) {
        var userUuid = _a.userUuid;
        return this.client.get("/users/c/".concat(userUuid), this.headers());
    };
    /**
     * Updates the authentication credentials and invalidates previous tokens (Legacy backend (drive-server))
     * @param payload
     *
     * @returns {Promise<{token: string, newToken: string}>} A promise that returns new tokens for this user.
     */
    Users.prototype.changePasswordLegacy = function (payload) {
        return this.client.patch('/user/password', {
            currentPassword: payload.currentEncryptedPassword,
            newPassword: payload.newEncryptedPassword,
            newSalt: payload.newEncryptedSalt,
            mnemonic: payload.encryptedMnemonic,
            privateKey: payload.encryptedPrivateKey,
        }, this.headers());
    };
    /**
     * Updates the authentication credentials and invalidates previous tokens (New backend (drive-server-wip))
     * @param payload
     *
     * @returns {Promise<{token: string, newToken: string}>} A promise that returns new tokens for this user.
     */
    Users.prototype.changePassword = function (payload) {
        return this.client.patch('/users/password', {
            currentPassword: payload.currentEncryptedPassword,
            newPassword: payload.newEncryptedPassword,
            newSalt: payload.newEncryptedSalt,
            mnemonic: payload.encryptedMnemonic,
            privateKey: payload.encryptedPrivateKey,
            encryptVersion: payload.encryptVersion,
        }, this.headers());
    };
    /**
     * Pre registers an email
     * @param email
     * @returns {Promise<PreCreateUserResponse>} A promise that returns a public key for this user.
     */
    Users.prototype.preRegister = function (email) {
        return this.client.post('/users/pre-create', {
            email: email,
        }, this.headers());
    };
    /**
     * Updates a user profile
     * @param payload
     */
    Users.prototype.updateProfile = function (payload) {
        return this.client.patch('/user/profile', payload, this.headers());
    };
    /**
     * Updates a user avatar
     * @param payload
     */
    Users.prototype.updateAvatar = function (payload) {
        var formData = new FormData();
        formData.set('avatar', payload.avatar);
        return this.client.put('/user/avatar', formData, this.headers());
    };
    /**
     * Delete current user avatar
     */
    Users.prototype.deleteAvatar = function () {
        return this.client.delete('/user/avatar', this.headers());
    };
    /**
     * Gets all friend invites created by this user
     */
    Users.prototype.getFriendInvites = function () {
        return this.client.get('/user/invite', this.headers());
    };
    /**
     * Sends verification email
     */
    Users.prototype.sendVerificationEmail = function () {
        return this.client.post('/user/sendVerificationEmail', {}, this.headers());
    };
    /**
     * Verifies user email
     */
    Users.prototype.verifyEmail = function (payload) {
        return this.client.post('/user/verifyEmail', payload, this.headers());
    };
    /**
     * Change user email by new email
     *
     * @param {string} newEmail
     *
     * @returns {Promise<void>}
     */
    Users.prototype.changeUserEmail = function (newEmail) {
        return this.client.post('users/attempt-change-email', {
            newEmail: newEmail,
        }, this.headers());
    };
    /**
     * Verify user email change
     *
     * @param {string} encryptedAttemptChangeEmailId
     *
     * @returns {Promise<VerifyEmailChangeResponse>}
     */
    Users.prototype.verifyEmailChange = function (encryptedAttemptChangeEmailId) {
        return this.client.post("users/attempt-change-email/".concat(encryptedAttemptChangeEmailId, "/accept"), {}, this.headers());
    };
    /**
     * Check if user email change verification link is expired
     *
     * @param {string} encryptedAttemptChangeEmailId
     *
     * @returns {Promise<CheckChangeEmailExpirationResponse>}
     */
    Users.prototype.checkChangeEmailExpiration = function (encryptedAttemptChangeEmailId) {
        return this.client.get("users/attempt-change-email/".concat(encryptedAttemptChangeEmailId, "/verify-expiration"), this.headers());
    };
    /**
     * Get public key of given email
     */
    Users.prototype.getPublicKeyByEmail = function (_a) {
        var email = _a.email;
        return this.client.get("/users/public-key/".concat(email), this.headers());
    };
    Users.prototype.headers = function () {
        return (0, headers_1.headersWithToken)(this.appDetails.clientName, this.appDetails.clientVersion, this.apiSecurity.token);
    };
    return Users;
}());
exports.Users = Users;
