"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var query_string_1 = __importDefault(require("query-string"));
var utils_1 = require("../../utils");
var PhotosSubmodule = /** @class */ (function () {
    function PhotosSubmodule(model) {
        this.model = model;
    }
    PhotosSubmodule.prototype.getPhotoById = function (photoId) {
        var _this = this;
        return axios_1.default
            .get("".concat(this.model.baseUrl, "/photos/").concat(photoId), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) { return _this.parse(res.data); })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.getPhotosSorted = function (filter, sort, skip, limit, includeDownloadLinks) {
        var _this = this;
        var query = query_string_1.default.stringify(__assign(__assign(__assign(__assign({}, filter), { skip: skip, limit: limit }), sort), { includeDownloadLinks: includeDownloadLinks === true }));
        if (skip < 0) {
            throw new Error('Invalid skip. Skip should be positive. Provided skip was: ' + skip);
        }
        return axios_1.default
            .get("".concat(this.model.baseUrl, "/photos/sorted?").concat(query), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) { return ({
            results: res.data.results.map(function (photoJson) { return _this.parse(photoJson); }),
            bucketId: res.data.bucketId,
        }); })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.getPhotos = function (filter, skip, limit, includeDownloadLinks) {
        var _this = this;
        if (skip === void 0) { skip = 0; }
        if (limit === void 0) { limit = 1; }
        var query = query_string_1.default.stringify(__assign(__assign({}, filter), { skip: skip, limit: limit, includeDownloadLinks: includeDownloadLinks }));
        if (skip < 0) {
            throw new Error('Invalid skip. Skip should be positive. Provided skip was: ' + skip);
        }
        return axios_1.default
            .get("".concat(this.model.baseUrl, "/photos/?").concat(query), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) { return ({
            results: res.data.results.map(function (photoJson) { return _this.parse(photoJson); }),
            bucketId: res.data.bucketId,
        }); })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.createPhoto = function (data) {
        var _this = this;
        return axios_1.default
            .post("".concat(this.model.baseUrl, "/photos"), data, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) { return _this.parse(res.data); })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.findOrCreatePhoto = function (data) {
        var _this = this;
        return axios_1.default
            .post("".concat(this.model.baseUrl, "/photos/photo/exists"), data, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) { return _this.parse(res.data); })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.deletePhotosById = function (photos) {
        return axios_1.default
            .delete("".concat(this.model.baseUrl, "/photos/photos"), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
            data: {
                photos: photos,
            },
        })
            .then(function () { return undefined; })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.deletePhotoById = function (photoId) {
        return axios_1.default
            .delete("".concat(this.model.baseUrl, "/photos/").concat(photoId), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function () { return undefined; })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.trashPhotosById = function (photos) {
        return axios_1.default
            .post("".concat(this.model.baseUrl, "/photos/photos/trash"), {
            photos: photos,
        }, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function () { return undefined; })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.trashPhotoById = function (photoId) {
        return axios_1.default
            .post("".concat(this.model.baseUrl, "/photos/").concat(photoId, "/trash"), {}, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function () { return undefined; })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.getUsage = function () {
        return axios_1.default
            .get("".concat(this.model.baseUrl, "/photos/usage"), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (result) {
            return result.data;
        })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.photosExists = function (photosExistPayload) {
        var _this = this;
        return axios_1.default
            .post("".concat(this.model.baseUrl, "/photos/exists"), { photos: photosExistPayload }, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (res) {
            return res.data.photos.map(function (result) {
                if ('id' in result) {
                    return __assign(__assign({}, _this.parse(result)), { exists: true });
                }
                else {
                    return __assign(__assign({}, result), { takenAt: new Date(result.takenAt) });
                }
            });
        })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.updatePhoto = function (photoId, data) {
        return axios_1.default
            .patch("".concat(this.model.baseUrl, "/photos/").concat(photoId), data, {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (result) {
            return result.data;
        })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.getCount = function () {
        return axios_1.default
            .get("".concat(this.model.baseUrl, "/photos/count"), {
            headers: {
                Authorization: "Bearer ".concat(this.model.accessToken),
            },
        })
            .then(function (result) { return result.data; })
            .catch(function (err) {
            throw new Error((0, utils_1.extractAxiosErrorMessage)(err));
        });
    };
    PhotosSubmodule.prototype.parse = function (json) {
        return __assign(__assign({}, json), { takenAt: new Date(json.takenAt), statusChangedAt: new Date(json.statusChangedAt), createdAt: new Date(json.createdAt), updatedAt: new Date(json.updatedAt) });
    };
    return PhotosSubmodule;
}());
exports.default = PhotosSubmodule;
