"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.basicHeaders = basicHeaders;
exports.basicHeadersWithPassword = basicHeadersWithPassword;
exports.headersWithToken = headersWithToken;
exports.headersWithTokenAndPassword = headersWithTokenAndPassword;
exports.headersWithBasicAuth = headersWithBasicAuth;
exports.headersWithAuthToken = headersWithAuthToken;
exports.addResourcesTokenToHeaders = addResourcesTokenToHeaders;
function basicHeaders(clientName, clientVersion) {
    return {
        'content-type': 'application/json; charset=utf-8',
        'internxt-version': clientVersion,
        'internxt-client': clientName,
    };
}
function basicHeadersWithPassword(clientName, clientVersion, password) {
    return {
        'content-type': 'application/json; charset=utf-8',
        'internxt-version': clientVersion,
        'internxt-client': clientName,
        'x-share-password': password,
    };
}
function headersWithToken(clientName, clientVersion, token, workspaceToken, customHeaders) {
    var headers = basicHeaders(clientName, clientVersion);
    var extra = {
        Authorization: 'Bearer ' + token,
    };
    if (workspaceToken !== undefined) {
        extra['x-internxt-workspace'] = workspaceToken;
    }
    return __assign(__assign(__assign({}, headers), extra), customHeaders);
}
function headersWithTokenAndPassword(clientName, clientVersion, token, workspaceToken, password) {
    var headers = headersWithToken(clientName, clientVersion, token, workspaceToken);
    var extra = {
        'x-share-password': password,
    };
    return __assign(__assign({}, headers), extra);
}
function headersWithBasicAuth(clientName, clientVersion, auth, workspaceToken) {
    var headers = basicHeaders(clientName, clientVersion);
    var token = "".concat(auth.username, ":").concat(auth.password);
    var encodedToken = Buffer.from(token).toString('base64');
    var extra = {
        Authorization: 'Basic ' + encodedToken,
    };
    if (workspaceToken !== undefined) {
        extra['x-internxt-workspace'] = workspaceToken;
    }
    return __assign(__assign({}, headers), extra);
}
function headersWithAuthToken(clientName, clientVersion, token, workspaceToken) {
    var headers = basicHeaders(clientName, clientVersion);
    var extra = {};
    if (workspaceToken !== undefined) {
        extra['x-internxt-workspace'] = workspaceToken;
    }
    return __assign(__assign(__assign({}, headers), { 'x-token': token }), extra);
}
function addResourcesTokenToHeaders(headers, resourcesToken) {
    if (resourcesToken && resourcesToken.length > 0) {
        return __assign(__assign({}, headers), { 'internxt-resources-token': resourcesToken });
    }
    return headers;
}
